#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const inquirer = require("inquirer");
const path = require("path");
const tmp_1 = require("tmp");
const yargsParser = require("yargs-parser");
const output_1 = require("./output");
const shared_1 = require("./shared");
const tsVersion = '3.9.3';
const angularCliVersion = '10.0.0-rc.0';
const parsedArgs = yargsParser(process.argv, {
    string: [],
    boolean: ['help', 'interactive'],
});
if (parsedArgs.help) {
    showHelp();
    process.exit(0);
}
determineWorkspaceName(parsedArgs).then((name) => {
    return determineCli().then((cli) => {
        const tmpDir = createSandbox(shared_1.determinePackageManager(), cli);
        createApp(tmpDir, cli, name);
        shared_1.showNxWarning(name);
    });
});
function showHelp() {
    console.log(`
  Usage: create-kikstart-ui <name> [options] [new workspace options]

  Create a new Kikstart UI app

  Options:

    name                      workspace name (e.g., org name)
`);
}
function determineWorkspaceName(args) {
    const workspaceName = args._[2];
    if (workspaceName) {
        return Promise.resolve(workspaceName);
    }
    return inquirer
        .prompt([
        {
            name: 'WorkspaceName',
            message: `Workspace name (e.g., org name)    `,
            type: 'string',
        },
    ])
        .then((a) => {
        if (!a.WorkspaceName) {
            output_1.output.error({
                title: 'Invalid workspace name',
                bodyLines: [`Workspace name cannot be empty`],
            });
            process.exit(1);
        }
        return a.WorkspaceName;
    });
}
function determineCli() {
    const angular = {
        package: '@angular/cli',
        version: angularCliVersion,
        command: 'ng',
    };
    return Promise.resolve(angular);
}
function createSandbox(packageManager, cli) {
    console.log(` Creating sandbox for installation...`);
    const tmpDir = tmp_1.dirSync().name;
    fs_1.writeFileSync(path.join(tmpDir, 'package.json'), JSON.stringify({
        dependencies: {
            [cli.package]: cli.version,
            typescript: tsVersion,
        },
        license: 'MIT',
    }));
    child_process_1.execSync(`${packageManager} install --silent`, {
        cwd: tmpDir,
        stdio: [0, 1, 2],
    });
    return tmpDir;
}
function createApp(tmpDir, cli, name) {
    const command = `new ${name}  --strict --style=scss --routing`;
    console.log(command);
    child_process_1.execSync(`"${path.join(tmpDir, 'node_modules', '.bin', cli.command)}" ${command}`, {
        stdio: [0, 1, 2],
    });
    const projectDir = path.join(process.cwd(), name);
    child_process_1.execSync(`${cli.command} add @kikstart-ui/schematics`, {
        cwd: projectDir,
        stdio: [0, 1, 2],
    });
}
//# sourceMappingURL=create-kikstart-ui.js.map